/*
	This file is part of ldraw.

	ldraw is free software: you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	ldraw is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with ldraw.  If not, see <http://www.gnu.org/licenses/>.
    
    Copyright (C) 2008 Lucas Hermann Negri
*/

#ifndef LDRAW_LDRAW
#define LDRAW_LDRAW

#define LIB_NAME "ldraw"
#define LIB_VERSION "0.9"

/* Lua headers */
#include <lua.h>
#include <lauxlib.h>

/* C headers */
#include <stdlib.h>
#include <string.h>

/* Integration with lgui? */
#ifdef HAVE_GTK
	#include <gtk/gtk.h>
	#include <lobj/types.h> /* For Object struct */
	#define BOOL gboolean

	int ldraw_context_create_from_drawable(lua_State* L);
	int ldraw_context_get_from_print_context(lua_State* L);
	int ldraw_context_set_source_color(lua_State* L);
	int ldraw_context_set_source_pixbuf(lua_State* L);
	int ldraw_pango_context_layout_path(lua_State* L);
	int ldraw_pango_context_show_layout(lua_State* L);
	int ldraw_pango_context_update_layout(lua_State* L);
#else
	#define BOOL char
	#define TRUE 1
	#define FALSE 0
#endif

/* Cairo */
#include <cairo.h>
#include <cairo-pdf.h>
#include <cairo-ps.h>
#include <cairo-svg.h>
#include "types.h"

/**
 * Return the library version.
 */
int ldraw_version(lua_State* L);

/* Begin of cairo functions */

int ldraw_context_create(lua_State* L);
int ldraw_context_status(lua_State* L);
int ldraw_context_save(lua_State* L);
int ldraw_context_restore(lua_State* L);
int ldraw_context_destroy(lua_State* L);
int ldraw_context_set_source_rgb(lua_State* L);
int ldraw_context_set_source_rgba(lua_State* L);
int ldraw_context_set_source_surface(lua_State* L);
int ldraw_context_paint(lua_State* L);
int ldraw_context_paint_with_alpha(lua_State* L);
int ldraw_context_select_font_face(lua_State* L);
int ldraw_context_set_font_size(lua_State* L);
int ldraw_context_move_to(lua_State* L);
int ldraw_context_line_to(lua_State* L);
int ldraw_context_curve_to(lua_State* L);
int ldraw_context_rel_move_to(lua_State* L);
int ldraw_context_rel_line_to(lua_State* L);
int ldraw_context_rel_curve_to(lua_State* L);
int ldraw_context_close_path(lua_State* L);
int ldraw_context_arc(lua_State* L);
int ldraw_context_arc_negative(lua_State* L);
int ldraw_context_show_text(lua_State* L);
int ldraw_context_set_dash(lua_State* L);
int ldraw_context_set_line_width(lua_State* L);
int ldraw_context_set_line_cap(lua_State* L);
int ldraw_context_set_line_join(lua_State* L);
int ldraw_context_rectangle(lua_State* L);
int ldraw_context_stroke(lua_State* L);
int ldraw_context_fill(lua_State* L);
int ldraw_context_set_antialias(lua_State* L);
int ldraw_context_get_antialias(lua_State* L);
int ldraw_context_translate(lua_State* L);
int ldraw_context_scale(lua_State* L);
int ldraw_context_rotate(lua_State* L);
int ldraw_context_clip(lua_State* L);
int ldraw_context_stroke_preserve(lua_State* L);
int ldraw_context_fill_preserve(lua_State* L);
int ldraw_context_transform(lua_State* L);
int ldraw_context_set_source(lua_State* L);
int ldraw_context_mask(lua_State* L);
int ldraw_context_mask_surface(lua_State* L);
int ldraw_context_tostring(lua_State* L);

/* Surface */

int ldraw_image_surface_create(lua_State* L);
int ldraw_image_surface_create_from_png(lua_State* L);
int ldraw_surface_destroy(lua_State* L);
int ldraw_surface_create_pdf(lua_State* L);
int ldraw_surface_create_svg(lua_State* L);
int ldraw_surface_create_ps(lua_State* L);
int ldraw_surface_write_to_png(lua_State* L);
int ldraw_surface_get_size(lua_State* L);
int ldraw_surface_status(lua_State* L);
int ldraw_surface_tostring(lua_State* L);

/* Patterns */

int ldraw_pattern_destroy(lua_State* L);
int ldraw_pattern_create_linear(lua_State* L);
int ldraw_pattern_create_radial(lua_State* L);
int ldraw_pattern_add_color_stop_rgb(lua_State* L);
int ldraw_pattern_add_color_stop_rgba(lua_State* L);
int ldraw_pattern_tostring(lua_State* L);

/* Matrix */

int ldraw_matrix_create(lua_State* L);
int ldraw_matrix_destroy(lua_State* L);
int ldraw_matrix_init(lua_State* L);
int ldraw_matrix_init_identity(lua_State* L);
int ldraw_matrix_translate(lua_State* L);
int ldraw_matrix_rotate(lua_State* L);
int ldraw_matrix_scale(lua_State* L);
int ldraw_matrix_invert(lua_State* L);
int ldraw_matrix_multiply(lua_State* L);
int ldraw_matrix_transform_distance(lua_State* L);
int ldraw_matrix_transform_point(lua_State* L);
int ldraw_matrix_tostring(lua_State* L);

#endif
